@@ -19,6 +19,8 @@ clean_up = [
     ".out",
     ".fdb_latexmk",
     ".fls",
+    ".xdv",
+    ".dvi",
 ]
 
 
@@ -60,11 +62,15 @@ def clean_aux(paths):
             pass
 
 
-parser = argparse.ArgumentParser(description="""Basic usage: latexcornouaille""")
+def recompile_all(path_to_watch, latex_engine):
+    cmd = f"latexmk -interaction=nonstopmode -{latex_engine}"
+    print(cmd)
+    subprocess.call(cmd, shell=True)
+    subprocess.call(cmd, shell=True)
+    clean_aux([path_to_watch])
 
 
-def main():
-    path_to_watch = os.getcwd()
+def watch(path_to_watch, latex_engine):
     print("Démarrage de la surveillance.")
     print(f"Dossier: {path_to_watch}")
     paths = initilisation(path_to_watch)
@@ -81,12 +87,57 @@ def main():
                 else:
                     output = file["path"]
                 print(output)
-                cmd = f"latexmk \"{file['name']}\" -interaction=nonstopmode -xelatex -output-directory=\"{os.path.join(file['path'])}\""
+                cmd = f"latexmk \"{file['name']}\" -interaction=nonstopmode -{latex_engine} -output-directory=\"{os.path.join(file['path'])}\""
                 print(cmd)
                 subprocess.call(cmd, shell=True)
             before = after
             clean_aux(paths)
 
 
+def define_latex_engine(args):
+    if args.lualatex:
+        print("lualatex")
+        return "lualatex"
+    else:
+        print("xelatex")
+        return "xelatex"
+
+
+def main():
+    path_to_watch = os.getcwd()
+    parser = argparse.ArgumentParser(description="""Basic usage: latexcor""")
+    parser.add_argument(
+        "--clean",
+        action="store_true",
+        default=False,
+        help="clean all aux files in current directory",
+    )
+    parser.add_argument(
+        "--recompile",
+        action="store_true",
+        default=False,
+        help="recompile all files in current directory",
+    )
+    parser.add_argument(
+        "--xelatex", action="store_true", default=True, help="xelatex default True"
+    )
+    parser.add_argument(
+        "--lualatex", action="store_true", default=False, help="lualatex default False"
+    )
+    args = parser.parse_args()
+    if args.clean:
+        print(f"Nettoyage du dossier: {path_to_watch}")
+        clean_aux([path_to_watch])
+        print("Fait")
+    elif args.recompile:
+        latex_engine = define_latex_engine(args)
+        print("Recompile tout")
+        recompile_all(path_to_watch, latex_engine)
+        print("Fait")
+    else:
+        latex_engine = define_latex_engine(args)
+        watch(path_to_watch, latex_engine)
+
+
 if __name__ == "__main__":
     main()
